@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2018 Intel Corporation.
+ * Copyright (C) 2014 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -116,7 +116,7 @@ enum {
 
     /*
      * This option touches first byte of all pages in address range starting from "addr" to "addr" + "size"
-     * by read and write (so the content will be overwitten by the same data as it was read).
+     * by read and write (so the content will be overwritten by the same data as it was read).
      */
     HBW_TOUCH_PAGES      = (1 << 0)
 };
@@ -233,6 +233,13 @@ void *hbw_realloc(void *ptr, size_t size);
  */
 void hbw_free(void *ptr);
 
+/*
+ * Returns the number of usable bytes in the block pointed to by ptr, a pointer
+ * to a block of memory allocated by hbw_malloc(), hbw_calloc(), hbw_realloc(),
+ * hbw_posix_memalign(), or hbw_posix_memalign_psize().
+ */
+size_t hbw_malloc_usable_size(void *ptr);
+
 #ifdef __cplusplus
 }
 #endif
