@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 - 2018 Intel Corporation.
+ * Copyright (C) 2017 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,4 +27,10 @@
 #include <memkind.h>
 
 void heap_manager_init(struct memkind *kind);
-void heap_manager_free(struct memkind *kind, void *ptr);
+void heap_manager_free(void *ptr);
+size_t heap_manager_malloc_usable_size(void *ptr);
+void *heap_manager_realloc(void *ptr, size_t size);
+struct memkind *heap_manager_detect_kind(void *ptr);
+int heap_manager_update_cached_stats(void);
+int heap_manager_get_stat(memkind_stat_type stat, size_t *value);
+void *heap_manager_defrag_reallocate(void *ptr);
