@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 - 2018 Intel Corporation.
+ * Copyright (C) 2016 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,6 @@
 extern "C" {
 #endif
 
-#ifndef MEMKIND_INTERNAL_API
-#warning "DO NOT INCLUDE THIS FILE! IT IS INTERNAL MEMKIND API AND SOON WILL BE REMOVED FROM BIN & DEVEL PACKAGES"
-#endif
-
 #include "memkind.h"
 
 #include <stdbool.h>
@@ -48,10 +44,6 @@ extern "C" {
 #   define MEMKIND_EXPORT __attribute__((visibility("default")))
 #endif
 
-#ifndef JE_PREFIX
-#error "Can't find JE_PREFIX define. Define one or use build.sh script."
-#endif
-
 // This ladder call is required due to meanders of C's preprocessor logic.
 // Without it, JE_PREFIX would be used directly (i.e. 'JE_PREFIX') and not
 // substituted with defined value.
@@ -72,9 +64,6 @@ extern "C" {
 #define jemk_dallocx                JE_SYMBOL(dallocx)
 #define jemk_malloc_usable_size     JE_SYMBOL(malloc_usable_size)
 
-/// \note EXPERIMENTAL API
-int je_get_defrag_hint(void *ptr, int *bin_util, int *run_util);
-
 enum memkind_const_private {
     MEMKIND_NAME_LENGTH_PRIV = 64
 };
@@ -97,10 +86,13 @@ struct memkind_ops {
                                unsigned long maxnode);
     int (* get_arena)(struct memkind *kind, unsigned int *arena, size_t size);
     int (* check_available)(struct memkind *kind);
-    int (* check_addr)(struct memkind *kind, void *addr);
     void (* init_once)(void);
     int (* finalize)(struct memkind *kind);
-    size_t (* malloc_usable_size)(struct memkind *kind, void *addr);
+    size_t (* malloc_usable_size)(struct memkind *kind, void *ptr);
+    int (* update_memory_usage_policy)(struct memkind *kind,
+                                       memkind_mem_usage_policy policy);
+    int (* get_stat)(memkind_t kind, memkind_stat_type stat, size_t *value);
+    void *(* defrag_reallocate)(struct memkind *kind, void *ptr);
 };
 
 struct memkind {
@@ -117,6 +109,12 @@ struct memkind {
     unsigned int arena_zero; // index first jemalloc arena of this kind
 };
 
+struct memkind_config {
+    const char *pmem_dir;            //PMEM kind path
+    size_t pmem_size;                //PMEM kind size
+    memkind_mem_usage_policy policy; //kind memory usage policy
+};
+
 void memkind_init(memkind_t kind, bool check_numa);
 
 void *kind_mmap(struct memkind *kind, void *addr, size_t size);
