@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2018 Intel Corporation.
+ * Copyright (C) 2014 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,27 +40,47 @@
 #include <jemalloc/jemalloc.h>
 #include <utmpx.h>
 #include <sched.h>
-#include <smmintrin.h>
 #include <limits.h>
 #include <sys/mman.h>
+#include <sys/param.h>
 #include <assert.h>
 
 #include "config.h"
 
 #define HUGE_PAGE_SIZE (1ull << MEMKIND_MASK_PAGE_SIZE_2MB)
+#define PAGE_2_BYTES(x) ((x) << 12)
+
+static const char *const global_stats[MEMKIND_STAT_TYPE_MAX_VALUE] = {
+    "stats.resident",
+    "stats.active",
+    "stats.allocated"
+};
+
+#define ARENA_STAT_MAX 2
+
+struct stats_arena {
+    const char *stats[ARENA_STAT_MAX];
+    unsigned stats_no;
+};
+
+static const struct stats_arena arena_stats [MEMKIND_STAT_TYPE_MAX_VALUE] = {
+    { .stats = {"stats.arenas.%u.resident", NULL}, .stats_no = 1},
+    { .stats = {"stats.arenas.%u.pactive", NULL}, .stats_no = 1},
+    { .stats = {"stats.arenas.%u.small.allocated", "stats.arenas.%u.large.allocated"}, .stats_no = 2},
+};
 
 static void *jemk_mallocx_check(size_t size, int flags);
 static void *jemk_rallocx_check(void *ptr, size_t size, int flags);
 static void tcache_finalize(void *args);
 
-static unsigned int integer_log2(unsigned int v)
+static unsigned integer_log2(unsigned v)
 {
     return (sizeof(unsigned) * 8) - (__builtin_clz(v) + 1);
 }
 
-static unsigned int round_pow2_up(unsigned int v)
+static unsigned round_pow2_up(unsigned v)
 {
-    unsigned int v_log2 = integer_log2(v);
+    unsigned v_log2 = integer_log2(v);
 
     if (v != 1 << v_log2) {
         v = 1 << (v_log2 + 1);
@@ -68,17 +88,12 @@ static unsigned int round_pow2_up(unsigned int v)
     return v;
 }
 
-static int min_int(int a, int b)
-{
-    return a > b ? b : a;
-}
-
 MEMKIND_EXPORT int memkind_set_arena_map_len(struct memkind *kind)
 {
     if (kind->ops->get_arena == memkind_bijective_get_arena) {
         kind->arena_map_len = 1;
     } else if (kind->ops->get_arena == memkind_thread_get_arena) {
-        char *arena_num_env = getenv("MEMKIND_ARENA_NUM_PER_KIND");
+        char *arena_num_env = secure_getenv("MEMKIND_ARENA_NUM_PER_KIND");
 
         if (arena_num_env) {
             unsigned long int arena_num_value = strtoul(arena_num_env, NULL, 10);
@@ -94,7 +109,7 @@ MEMKIND_EXPORT int memkind_set_arena_map_len(struct memkind *kind)
             int calculated_arena_num = numa_num_configured_cpus() * 4;
 
 #if ARENA_LIMIT_PER_KIND != 0
-            calculated_arena_num = min_int(ARENA_LIMIT_PER_KIND, calculated_arena_num);
+            calculated_arena_num = MIN((ARENA_LIMIT_PER_KIND), calculated_arena_num);
 #endif
             kind->arena_map_len = calculated_arena_num;
         }
@@ -114,13 +129,16 @@ static bool memkind_hog_memory;
 
 static void arena_config_init()
 {
-    const char *str = getenv("MEMKIND_HOG_MEMORY");
+    const char *str = secure_getenv("MEMKIND_HOG_MEMORY");
     memkind_hog_memory = str && str[0] == '1';
 
     arena_init_status = pthread_key_create(&tcache_key, tcache_finalize);
 }
 
-#define MALLOCX_ARENA_MAX 0xffe // copy-pasted from jemalloc/internal/jemalloc_internal.h
+#define MALLOCX_ARENA_MAX           0xffe        // copy-pasted from jemalloc/internal/jemalloc_internal.h
+#define DIRTY_DECAY_MS_DEFAULT      10000        // copy-pasted from jemalloc/internal/arena_types.h DIRTY_DECAY_MS_DEFAULT
+#define DIRTY_DECAY_MS_CONSERVATIVE     0
+
 static struct memkind *arena_registry_g[MALLOCX_ARENA_MAX];
 static pthread_mutex_t arena_registry_write_lock;
 
@@ -172,17 +190,14 @@ void *arena_extent_alloc(extent_hooks_t *extent_hooks,
                          bool *commit,
                          unsigned arena_ind)
 {
-    int err;
-    void *addr = NULL;
-
     struct memkind *kind = get_kind_by_arena(arena_ind);
 
-    err = memkind_check_available(kind);
+    int err = memkind_check_available(kind);
     if (err) {
         return NULL;
     }
 
-    addr = kind_mmap(kind, new_addr, size);
+    void *addr = kind_mmap(kind, new_addr, size);
     if (addr == MAP_FAILED) {
         return NULL;
     }
@@ -257,13 +272,11 @@ bool arena_extent_purge(extent_hooks_t *extent_hooks,
                         size_t length,
                         unsigned arena_ind)
 {
-    int err;
-
     if (memkind_hog_memory) {
         return true;
     }
 
-    err = madvise(addr + offset, length, MADV_DONTNEED);
+    int err = madvise(addr + offset, length, MADV_DONTNEED);
     return (err != 0);
 }
 
@@ -324,8 +337,7 @@ extent_hooks_t *get_extent_hooks_by_kind(struct memkind *kind)
 MEMKIND_EXPORT int memkind_arena_create_map(struct memkind *kind,
                                             extent_hooks_t *hooks)
 {
-    int err = 0;
-    size_t unsigned_size = sizeof(unsigned int);
+    int err;
 
     pthread_once(&arena_config_once, arena_config_init);
     if(arena_init_status) {
@@ -338,16 +350,18 @@ MEMKIND_EXPORT int memkind_arena_create_map(struct memkind *kind,
     }
 #ifdef MEMKIND_TLS
     if (kind->ops->get_arena == memkind_thread_get_arena) {
-        pthread_key_create(&(kind->arena_key), jemk_free);
+        pthread_key_create(&(kind->arena_key), free);
     }
 #endif
 
-    pthread_mutex_lock(&arena_registry_write_lock);
-    unsigned i = 0;
+    if (pthread_mutex_lock(&arena_registry_write_lock) != 0)
+        assert(0 && "failed to acquire mutex");
+    unsigned i;
+    size_t unsigned_size = sizeof(unsigned int);
     kind->arena_zero = UINT_MAX;
     for(i = 0; i<kind->arena_map_len; i++) {
-        //create new arena with consecutive index
         unsigned arena_index;
+        //create new arena with consecutive index
         err = jemk_mallctl("arenas.create", (void *)&arena_index, &unsigned_size, NULL,
                            0);
         if(err) {
@@ -370,16 +384,15 @@ MEMKIND_EXPORT int memkind_arena_create_map(struct memkind *kind,
     }
 
 exit:
-    pthread_mutex_unlock(&arena_registry_write_lock);
+    if (pthread_mutex_unlock(&arena_registry_write_lock) != 0)
+        assert(0 && "failed to release mutex");
     return err;
 }
 
 MEMKIND_EXPORT int memkind_arena_create(struct memkind *kind,
                                         struct memkind_ops *ops, const char *name)
 {
-    int err = 0;
-
-    err = memkind_default_create(kind, ops, name);
+    int err = memkind_default_create(kind, ops, name);
     if (!err) {
         err = memkind_arena_create_map(kind, get_extent_hooks_by_kind(kind));
     }
@@ -388,12 +401,12 @@ MEMKIND_EXPORT int memkind_arena_create(struct memkind *kind,
 
 MEMKIND_EXPORT int memkind_arena_destroy(struct memkind *kind)
 {
-    char cmd[128];
-    unsigned int i;
-
     if (kind->arena_map_len) {
+        char cmd[128];
+        unsigned i;
 
-        pthread_mutex_lock(&arena_registry_write_lock);
+        if (pthread_mutex_lock(&arena_registry_write_lock) != 0)
+            assert(0 && "failed to acquire mutex");
 
         for (i = 0; i < kind->arena_map_len; ++i) {
             snprintf(cmd, 128, "arena.%u.destroy", kind->arena_zero + i);
@@ -401,7 +414,8 @@ MEMKIND_EXPORT int memkind_arena_destroy(struct memkind *kind)
             arena_registry_g[kind->arena_zero + i] = NULL;
         }
 
-        pthread_mutex_unlock(&arena_registry_write_lock);
+        if (pthread_mutex_unlock(&arena_registry_write_lock) != 0)
+            assert(0 && "failed to release mutex");
 
 #ifdef MEMKIND_TLS
         if (kind->ops->get_arena == memkind_thread_get_arena) {
@@ -420,8 +434,7 @@ int memkind_arena_finalize(struct memkind *kind)
 }
 
 // max allocation size to be cached by tcache mechanism
-// should be aligned with jemalloc opt.lg_tcache_max
-#define TCACHE_MAX (1<<12)
+#define TCACHE_MAX (1<<(JEMALLOC_TCACHE_CLASS))
 
 static void tcache_finalize(void *args)
 {
@@ -450,17 +463,35 @@ static inline int memkind_lookup_arena(void *ptr, unsigned int *arena)
     return 0;
 }
 
+MEMKIND_EXPORT struct memkind *memkind_arena_detect_kind(void *ptr)
+{
+    if (!ptr) {
+        return NULL;
+    }
+    struct memkind *kind = NULL;
+    unsigned arena;
+    int err = memkind_lookup_arena(ptr, &arena);
+    if (MEMKIND_LIKELY(!err)) {
+        kind = get_kind_by_arena(arena);
+    }
+
+    /* if no kind was associated with arena it means that allocation doesn't come from
+       jemk_*allocx API - it is jemk_*alloc API (MEMKIND_DEFAULT) */
+
+    return (kind) ? kind : MEMKIND_DEFAULT;
+}
+
 static inline int get_tcache_flag(unsigned partition, size_t size)
 {
 
-    // do not cache allocation larger than tcache_max nor those comming from non-static kinds
+    // do not cache allocation larger than tcache_max nor those coming from non-static kinds
     if(size > TCACHE_MAX || partition >= MEMKIND_NUM_BASE_KIND) {
         return MALLOCX_TCACHE_NONE;
     }
 
     unsigned *tcache_map = pthread_getspecific(tcache_key);
     if(tcache_map == NULL) {
-        tcache_map = jemk_calloc(MEMKIND_NUM_BASE_KIND, sizeof(unsigned));
+        tcache_map = calloc(MEMKIND_NUM_BASE_KIND, sizeof(unsigned));
         if(tcache_map == NULL) {
             return MALLOCX_TCACHE_NONE;
         }
@@ -482,10 +513,9 @@ static inline int get_tcache_flag(unsigned partition, size_t size)
 MEMKIND_EXPORT void *memkind_arena_malloc(struct memkind *kind, size_t size)
 {
     void *result = NULL;
-    int err = 0;
-    unsigned int arena;
+    unsigned arena;
 
-    err = kind->ops->get_arena(kind, &arena, size);
+    int err = kind->ops->get_arena(kind, &arena, size);
     if (MEMKIND_LIKELY(!err)) {
         result = jemk_mallocx_check(size,
                                     MALLOCX_ARENA(arena) | get_tcache_flag(kind->partition, size));
@@ -493,34 +523,52 @@ MEMKIND_EXPORT void *memkind_arena_malloc(struct memkind *kind, size_t size)
     return result;
 }
 
-MEMKIND_EXPORT void memkind_arena_free(struct memkind *kind, void *ptr)
+static void *memkind_arena_malloc_no_tcache(struct memkind *kind, size_t size)
 {
-    if (!kind && ptr != NULL) {
-        unsigned int arena;
-        int err = memkind_lookup_arena(ptr, &arena);
+    void *result = NULL;
+    if (kind == MEMKIND_DEFAULT) {
+        result = jemk_mallocx_check(size, MALLOCX_TCACHE_NONE);
+    } else {
+        unsigned arena;
+        int err = kind->ops->get_arena(kind, &arena, size);
         if (MEMKIND_LIKELY(!err)) {
-            kind = get_kind_by_arena(arena);
+            result = jemk_mallocx_check(size, MALLOCX_ARENA(arena) | MALLOCX_TCACHE_NONE);
         }
     }
+    return result;
+}
 
-    if (!kind) {
+MEMKIND_EXPORT void memkind_arena_free(struct memkind *kind, void *ptr)
+{
+    if (kind == MEMKIND_DEFAULT) {
         jemk_free(ptr);
     } else if (ptr != NULL) {
         jemk_dallocx(ptr, get_tcache_flag(kind->partition, 0));
     }
 }
 
+MEMKIND_EXPORT void memkind_arena_free_with_kind_detect(void *ptr)
+{
+    struct memkind *kind = memkind_arena_detect_kind(ptr);
+
+    memkind_arena_free(kind, ptr);
+}
+
+MEMKIND_EXPORT size_t memkind_arena_malloc_usable_size(void *ptr)
+{
+    return memkind_default_malloc_usable_size(NULL, ptr);
+}
+
 MEMKIND_EXPORT void *memkind_arena_realloc(struct memkind *kind, void *ptr,
                                            size_t size)
 {
-    int err = 0;
-    unsigned int arena;
+    unsigned arena;
 
     if (size == 0 && ptr != NULL) {
-        memkind_free(kind, ptr);
+        memkind_arena_free(kind, ptr);
         ptr = NULL;
     } else {
-        err = kind->ops->get_arena(kind, &arena, size);
+        int err = kind->ops->get_arena(kind, &arena, size);
         if (MEMKIND_LIKELY(!err)) {
             if (ptr == NULL) {
                 ptr = jemk_mallocx_check(size,
@@ -534,35 +582,66 @@ MEMKIND_EXPORT void *memkind_arena_realloc(struct memkind *kind, void *ptr,
     return ptr;
 }
 
-// TODO: function is workaround for PR#1302 in jemalloc upstream
-// and it should be removed/replaced with memkind_arena_calloc()
-// after PR will be merged
-MEMKIND_EXPORT void *memkind_arena_pmem_calloc(struct memkind *kind, size_t num,
-                                               size_t size)
+int memkind_arena_update_cached_stats(void)
 {
-    void *result = NULL;
-    int err = 0;
-    unsigned int arena;
+    uint64_t epoch = 1;
+    return jemk_mallctl("epoch", NULL, NULL, &epoch, sizeof(epoch));
+}
 
-    err = kind->ops->get_arena(kind, &arena, size);
-    if (MEMKIND_LIKELY(!err)) {
-        result = jemk_mallocx_check(num * size,
-                                    MALLOCX_ARENA(arena) | get_tcache_flag(kind->partition, size));
-        if (MEMKIND_LIKELY(result)) {
-            memset(result, 0, size);
+MEMKIND_EXPORT void *memkind_arena_realloc_with_kind_detect(void *ptr,
+                                                            size_t size)
+{
+    if (!ptr) {
+        errno = EINVAL;
+        return NULL;
+    }
+    struct memkind *kind = memkind_arena_detect_kind(ptr);
+    if (kind == MEMKIND_DEFAULT) {
+        return memkind_default_realloc(kind, ptr, size);
+    } else {
+        return memkind_arena_realloc(kind, ptr, size);
+    }
+}
+
+MEMKIND_EXPORT int memkind_arena_update_memory_usage_policy(
+    struct memkind *kind, memkind_mem_usage_policy policy)
+{
+    int err = MEMKIND_SUCCESS;
+    unsigned i;
+    ssize_t dirty_decay_val = 0;
+    switch ( policy ) {
+        case MEMKIND_MEM_USAGE_POLICY_DEFAULT:
+            dirty_decay_val = DIRTY_DECAY_MS_DEFAULT;
+            break;
+        case MEMKIND_MEM_USAGE_POLICY_CONSERVATIVE:
+            dirty_decay_val = DIRTY_DECAY_MS_CONSERVATIVE;
+            break;
+        default:
+            log_err("Unrecognized memory policy %d", policy);
+            return MEMKIND_ERROR_INVALID;
+    }
+
+    for (i = 0; i < kind->arena_map_len; ++i) {
+        char cmd[64];
+
+        snprintf(cmd, sizeof(cmd), "arena.%u.dirty_decay_ms", kind->arena_zero + i);
+        err = jemk_mallctl(cmd, NULL, NULL, (void *)&dirty_decay_val, sizeof(ssize_t));
+        if ( err ) {
+            log_err("Incorrect dirty_decay_ms value %zu", dirty_decay_val);
+            return MEMKIND_ERROR_INVALID;
         }
     }
-    return result;
+
+    return err;
 }
 
 MEMKIND_EXPORT void *memkind_arena_calloc(struct memkind *kind, size_t num,
                                           size_t size)
 {
     void *result = NULL;
-    int err = 0;
-    unsigned int arena;
+    unsigned arena;
 
-    err = kind->ops->get_arena(kind, &arena, size);
+    int err = kind->ops->get_arena(kind, &arena, size);
     if (MEMKIND_LIKELY(!err)) {
         result = jemk_mallocx_check(num * size,
                                     MALLOCX_ARENA(arena) | MALLOCX_ZERO | get_tcache_flag(kind->partition, size));
@@ -574,9 +653,8 @@ MEMKIND_EXPORT int memkind_arena_posix_memalign(struct memkind *kind,
                                                 void **memptr, size_t alignment,
                                                 size_t size)
 {
-    int err = 0;
-    unsigned int arena;
-    int errno_before;
+    int err;
+    unsigned arena;
 
     *memptr = NULL;
     err = kind->ops->get_arena(kind, &arena, size);
@@ -584,9 +662,12 @@ MEMKIND_EXPORT int memkind_arena_posix_memalign(struct memkind *kind,
         err = memkind_posix_check_alignment(kind, alignment);
     }
     if (MEMKIND_LIKELY(!err)) {
+        if (MEMKIND_UNLIKELY(size_out_of_bounds(size))) {
+            return 0;
+        }
         /* posix_memalign should not change errno.
            Set it to its previous value after calling jemalloc */
-        errno_before = errno;
+        int errno_before = errno;
         *memptr = jemk_mallocx_check(size,
                                      MALLOCX_ALIGN(alignment) | MALLOCX_ARENA(arena) | get_tcache_flag(
                                          kind->partition, size));
@@ -612,13 +693,17 @@ MEMKIND_EXPORT int memkind_thread_get_arena(struct memkind *kind,
     arena_tsd = pthread_getspecific(kind->arena_key);
 
     if (MEMKIND_UNLIKELY(arena_tsd == NULL)) {
-        arena_tsd = jemk_malloc(sizeof(unsigned int));
+        arena_tsd = malloc(sizeof(unsigned int));
         if (arena_tsd == NULL) {
             err = MEMKIND_ERROR_MALLOC;
-            log_err("jemk_malloc() failed.");
+            log_err("malloc() failed.");
         }
         if (!err) {
-            *arena_tsd = _mm_crc32_u64(0, (uint64_t)pthread_self()) %
+            // On glibc pthread_self() is incremented by 0x801000 for every
+            // thread (no matter the arch's word width).  This might change
+            // in the future, but even in the worst case the hash will
+            // degenerate to a single bucket with no loss of correctness.
+            *arena_tsd = ((uint64_t)pthread_self() >> 12) %
                          kind->arena_map_len;
             err = pthread_setspecific(kind->arena_key, arena_tsd) ?
                   MEMKIND_ERROR_RUNTIME : 0;
@@ -636,19 +721,20 @@ MEMKIND_EXPORT int memkind_thread_get_arena(struct memkind *kind,
  * For more read: https://www.akkadia.org/drepper/tls.pdf
  * We could consider using rdfsbase when it will arrive to linux kernel
  *
+ * This approach works only on glibc (and possibly similar implementations)
+ * but that covers our current needs.
+ *
  */
 static uintptr_t get_fs_base()
 {
-    uintptr_t fs_base;
-    asm ("movq %%fs:0, %0" : "=r" (fs_base));
-    return fs_base;
+    return (uintptr_t)pthread_self();
 }
 
 MEMKIND_EXPORT int memkind_thread_get_arena(struct memkind *kind,
                                             unsigned int *arena, size_t size)
 {
     unsigned int arena_idx;
-    // it's likely that each thread control block lies on diffrent page
+    // it's likely that each thread control block lies on different page
     // so we extracting page number with >> 12 to improve hashing
     arena_idx = (get_fs_base() >> 12) & kind->arena_map_mask;
     *arena = kind->arena_zero + arena_idx;
@@ -695,12 +781,158 @@ static void *jemk_rallocx_check(void *ptr, size_t size, int flags)
 
 void memkind_arena_init(struct memkind *kind)
 {
-    int err = 0;
     if (kind != MEMKIND_DEFAULT) {
-        err = memkind_arena_create_map(kind, get_extent_hooks_by_kind(kind));
+        int err = memkind_arena_create_map(kind, get_extent_hooks_by_kind(kind));
         if (err) {
             log_fatal("[%s] Failed to create arena map (error code:%d).", kind->name, err);
             abort();
         }
     }
 }
+
+static int memkind_arena_get_stat(struct memkind *kind, memkind_stat_type stat,
+                                  bool check_init, size_t *value)
+{
+    size_t sz = sizeof(size_t);
+    size_t temp_stat;
+    int err = MEMKIND_SUCCESS;
+    unsigned i, j;
+    char cmd[128];
+
+    *value = 0;
+    for (i = 0; i < kind->arena_map_len; ++i) {
+        if (check_init) {
+            bool is_init;
+            size_t sz_b_state = sizeof(is_init);
+            snprintf(cmd, 128, "arena.%u.initialized", kind->arena_zero + i);
+            err =  jemk_mallctl(cmd, (void *)&is_init, &sz_b_state, NULL, 0);
+            if (err) {
+                log_err("Error on getting initialized state of arena.");
+                return MEMKIND_ERROR_INVALID;
+            }
+            if (!is_init) {
+                continue;
+            }
+        }
+
+        for (j = 0; j < arena_stats[stat].stats_no; ++j) {
+            snprintf(cmd, 128, arena_stats[stat].stats[j], kind->arena_zero + i);
+            err = jemk_mallctl(cmd, &temp_stat, &sz, NULL, 0);
+            if (err) {
+                log_err("Error on getting arena statistic.");
+                return MEMKIND_ERROR_INVALID;
+            }
+            *value += temp_stat;
+        }
+    }
+    return err;
+}
+
+int memkind_arena_get_stat_with_check_init(struct memkind *kind,
+                                           memkind_stat_type stat, bool check_init, size_t *value)
+{
+    int status;
+    switch (stat) {
+        case MEMKIND_STAT_TYPE_RESIDENT:
+        case MEMKIND_STAT_TYPE_ALLOCATED:
+            status = memkind_arena_get_stat(kind, stat, check_init, value);
+            break;
+        case MEMKIND_STAT_TYPE_ACTIVE:
+            status = memkind_arena_get_stat(kind, stat, check_init, value);
+            *value = PAGE_2_BYTES(*value);
+            break;
+        default:
+            //not reached
+            return MEMKIND_ERROR_INVALID;
+            break;
+    }
+    return status;
+}
+
+int memkind_arena_get_kind_stat(struct memkind *kind, memkind_stat_type stat,
+                                size_t *value)
+{
+    return memkind_arena_get_stat_with_check_init(kind, stat, false, value);
+}
+
+int memkind_arena_get_global_stat(memkind_stat_type stat, size_t *value)
+{
+    size_t sz = sizeof(size_t);
+    int err = jemk_mallctl(global_stats[stat], value, &sz, NULL, 0);
+    if (err) {
+        log_err("Error on getting global statistic.");
+        return MEMKIND_ERROR_INVALID;
+    }
+    return err;
+}
+
+int memkind_arena_enable_background_threads(size_t threads_limit)
+{
+    bool background_thread_val = true;
+    int err;
+
+    if (threads_limit) {
+        err = jemk_mallctl("max_background_threads", NULL, NULL, &threads_limit,
+                           sizeof(size_t));
+        if (err) {
+            log_err("Error on setting threads limit");
+            return MEMKIND_ERROR_INVALID;
+        }
+    }
+    err = jemk_mallctl("background_thread", NULL, NULL, &background_thread_val,
+                       sizeof(bool));
+    if (err) {
+        log_err("Error on activating background thread");
+        return MEMKIND_ERROR_INVALID;
+    }
+    return err;
+}
+
+#define DEST_SLAB_END(begin, size) ((uintptr_t)begin+ (uintptr_t)size)
+
+struct mem_util_stats {
+    void *target_slab;      // address of the slab of a potential realloaction would go to ( NULL in case of large/huge allocation)
+    size_t nfree;           // number of free regions in the slab
+    size_t nregs;           // number of regions in the slab
+    size_t slab_size;       // size of the slab in bytes
+    size_t bin_nfree;       // total number of free regions in the bin the slab belongs to
+    size_t bin_nregs;       // total number of regions in the bin the slab belongs to
+};
+
+void *memkind_arena_defrag_reallocate_with_kind_detect (void *ptr)
+{
+    return memkind_arena_defrag_reallocate(memkind_detect_kind(ptr), ptr);
+}
+
+void *memkind_arena_defrag_reallocate(struct memkind *kind, void *ptr)
+{
+    if (!ptr) {
+        return NULL;
+    }
+
+    size_t out_sz = sizeof(struct mem_util_stats);
+    struct mem_util_stats out;
+    int err = jemk_mallctl("experimental.utilization.query", &out, &out_sz, &ptr,
+                           sizeof(ptr));
+    if (err) {
+        log_err("Error on get utilization query");
+        return NULL;
+    }
+
+    // Check if input pointer resides outside of potential reallocation slab
+    // Check if occupied regions inside the slab are below average occupied regions inside bin
+    // Check if there are some free regions in the destination slab
+    if (out.target_slab &&
+        ((ptr < out.target_slab) ||
+         (uintptr_t)ptr > DEST_SLAB_END(out.target_slab, out.slab_size)) &&
+        out.nfree * out.bin_nregs >= out.nregs * out.bin_nfree &&
+        out.nfree != 0) {
+        size_t size = memkind_malloc_usable_size(kind, ptr);
+        void *ptr_new = memkind_arena_malloc_no_tcache(kind, size);
+        if (MEMKIND_UNLIKELY(!ptr_new)) return NULL;
+        memcpy(ptr_new, ptr, size);
+        memkind_free(kind, ptr);
+        return ptr_new;
+    }
+    return NULL;
+}
