@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2018 Intel Corporation.
+ * Copyright (C) 2014 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -22,6 +22,7 @@
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <memkind/internal/memkind_arena.h>
 #include <memkind/internal/memkind_default.h>
 #include <memkind/internal/memkind_private.h>
 #include <memkind/internal/memkind_log.h>
@@ -35,10 +36,18 @@
 #include <jemalloc/jemalloc.h>
 #include <stdint.h>
 
+#include "config.h"
+
 #ifndef MADV_NOHUGEPAGE
 #define MADV_NOHUGEPAGE 15
 #endif
 
+static int memkind_default_get_kind_stat(struct memkind *kind,
+                                         memkind_stat_type stat, size_t *value)
+{
+    return memkind_arena_get_stat_with_check_init(kind, stat, true, value);
+}
+
 MEMKIND_EXPORT struct memkind_ops MEMKIND_DEFAULT_OPS = {
     .create = memkind_default_create,
     .destroy = memkind_default_destroy,
@@ -49,7 +58,9 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_DEFAULT_OPS = {
     .free = memkind_default_free,
     .init_once = memkind_default_init_once,
     .malloc_usable_size = memkind_default_malloc_usable_size,
-    .finalize = memkind_default_destroy
+    .finalize = memkind_default_destroy,
+    .get_stat = memkind_default_get_kind_stat,
+    .defrag_reallocate = memkind_arena_defrag_reallocate
 };
 
 MEMKIND_EXPORT int memkind_default_create(struct memkind *kind,
@@ -93,7 +104,8 @@ MEMKIND_EXPORT int memkind_default_posix_memalign(struct memkind *kind,
                                                   void **memptr, size_t alignment, size_t size)
 {
     if(MEMKIND_UNLIKELY(size_out_of_bounds(size))) {
-        return EINVAL;
+        *memptr = NULL;
+        return 0;
     }
     return jemk_posix_memalign(memptr, alignment, size);
 }
@@ -102,6 +114,7 @@ MEMKIND_EXPORT void *memkind_default_realloc(struct memkind *kind, void *ptr,
                                              size_t size)
 {
     if(MEMKIND_UNLIKELY(size_out_of_bounds(size))) {
+        jemk_free(ptr);
         return NULL;
     }
     return jemk_realloc(ptr, size);
