@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2017 Intel Corporation.
+ * Copyright (C) 2014 - 2019 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_GBTLB_OPS = {
     .calloc = memkind_arena_calloc,
     .posix_memalign = memkind_arena_posix_memalign,
     .realloc = memkind_arena_realloc,
-    .free = memkind_default_free,
+    .free = memkind_arena_free,
     .mmap = gbtlb_mmap,
     .check_available = memkind_hugetlb_check_available_2mb,
     .mbind = memkind_default_mbind,
@@ -52,7 +52,10 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_GBTLB_OPS = {
     .get_mbind_nodemask = memkind_hbw_get_mbind_nodemask,
     .get_arena = memkind_thread_get_arena,
     .init_once = memkind_hbw_gbtlb_init_once,
-    .finalize = memkind_arena_finalize
+    .malloc_usable_size = memkind_default_malloc_usable_size,
+    .finalize = memkind_arena_finalize,
+    .get_stat = memkind_arena_get_kind_stat,
+    .defrag_reallocate = memkind_arena_defrag_reallocate
 };
 
 MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_PREFERRED_GBTLB_OPS = {
@@ -62,7 +65,7 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_PREFERRED_GBTLB_OPS = {
     .calloc = memkind_arena_calloc,
     .posix_memalign = memkind_arena_posix_memalign,
     .realloc = memkind_arena_realloc,
-    .free = memkind_default_free,
+    .free = memkind_arena_free,
     .mmap = gbtlb_mmap,
     .check_available = memkind_hugetlb_check_available_2mb,
     .mbind = memkind_default_mbind,
@@ -71,7 +74,10 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_PREFERRED_GBTLB_OPS = {
     .get_mbind_nodemask = memkind_hbw_get_mbind_nodemask,
     .get_arena = memkind_thread_get_arena,
     .init_once = memkind_hbw_preferred_gbtlb_init_once,
-    .finalize = memkind_arena_finalize
+    .malloc_usable_size = memkind_default_malloc_usable_size,
+    .finalize = memkind_arena_finalize,
+    .get_stat = memkind_arena_get_kind_stat,
+    .defrag_reallocate = memkind_arena_defrag_reallocate
 };
 
 MEMKIND_EXPORT struct memkind_ops MEMKIND_GBTLB_OPS = {
@@ -81,20 +87,23 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_GBTLB_OPS = {
     .calloc = memkind_arena_calloc,
     .posix_memalign = memkind_arena_posix_memalign,
     .realloc = memkind_arena_realloc,
-    .free = memkind_default_free,
+    .free = memkind_arena_free,
     .mmap = gbtlb_mmap,
     .check_available = memkind_hugetlb_check_available_2mb,
     .get_mmap_flags = memkind_hugetlb_get_mmap_flags,
     .get_arena = memkind_thread_get_arena,
     .init_once = memkind_gbtlb_init_once,
-    .finalize = memkind_arena_finalize
+    .malloc_usable_size = memkind_default_malloc_usable_size,
+    .finalize = memkind_arena_finalize,
+    .get_stat = memkind_arena_get_kind_stat,
+    .defrag_reallocate = memkind_arena_defrag_reallocate
 };
 
 #define ONE_GB 1073741824ULL
 
 static void memkind_gbtlb_ceil_size(size_t *size)
 {
-    *size = *size % ONE_GB ? ((*size / ONE_GB) + 1) * ONE_GB : *size;
+    *size = (*size % ONE_GB) ? ((*size / ONE_GB) + 1) * ONE_GB : *size;
 }
 
 static void *gbtlb_mmap(struct memkind *kind, void *addr, size_t size)
