@@ -1,5 +1,5 @@
 /*
-* Copyright (C) 2016 - 2018 Intel Corporation.
+* Copyright (C) 2016 - 2019 Intel Corporation.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,6 @@
 #include "allocator_perf_tool/Stats.hpp"
 #include "allocator_perf_tool/Thread.hpp"
 #include "allocator_perf_tool/GTestAdapter.hpp"
-#include "allocator_perf_tool/PmemMockup.hpp"
-
-static const size_t PMEM_PART_SIZE = 0;
-extern const char  *PMEM_DIR;
 
 class AllocPerformanceTest: public :: testing::Test
 {
@@ -41,17 +37,10 @@ protected:
     void SetUp()
     {
         allocator_factory.initialize_allocator(AllocatorTypes::STANDARD_ALLOCATOR);
-
-        int err = memkind_create_pmem(PMEM_DIR, PMEM_PART_SIZE, &MEMKIND_PMEM_MOCKUP);
-        ASSERT_EQ(0, err);
-        ASSERT_TRUE(nullptr != MEMKIND_PMEM_MOCKUP);
     }
 
     void TearDown()
-    {
-        int err = memkind_destroy_kind(MEMKIND_PMEM_MOCKUP);
-        ASSERT_EQ(0, err);
-    }
+    {}
 
     float run(unsigned kind, unsigned call, size_t threads_number,
               size_t alloc_size, unsigned mem_operations_num)
@@ -76,7 +65,7 @@ protected:
             func_calls, //enable function calls
             allocator_types, //enable allocators
             11, //random seed
-            false, //does not log memory operations and statistics to csv file
+            false, //do not log memory operations and statistics to csv file
         };
 
         for (int i=0; i<threads_number; i++) {
@@ -1650,631 +1639,3 @@ TEST_F(AllocPerformanceTest,
     run_test(AllocatorTypes::MEMKIND_HBW_PREFERRED, FunctionCalls::REALLOC, 72,
              1572864, 10000);
 }
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 1, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 1, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 10,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_malloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::MALLOC, 72,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 1, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 1, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 10,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_calloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::CALLOC, 72,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 1, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 1,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 10,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_HBWMALLOC_ALLOCATOR_realloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::HBWMALLOC_ALLOCATOR, FunctionCalls::REALLOC, 72,
-             1572864, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 1, 100, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 1, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 10, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_malloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::MALLOC, 72, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 1, 100, 10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 1, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 10, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_calloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::CALLOC, 72, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_1_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 1, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_1_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 1, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_1_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 1, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_1_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 1, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_1_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 1, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_10_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 10, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_10_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 10, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_10_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 10, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_10_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 10, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_10_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 10, 1572864,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_72_thread_100_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 72, 100,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_72_thread_4096_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 72, 4096,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_72_thread_1000_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 72, 1000,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_72_thread_1001_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 72, 1001,
-             10000);
-}
-
-TEST_F(AllocPerformanceTest,
-       test_TC_MEMKIND_MEMKIND_PMEM_realloc_72_thread_1572864_bytes)
-{
-    run_test(AllocatorTypes::MEMKIND_PMEM, FunctionCalls::REALLOC, 72, 1572864,
-             10000);
-}
