@@ -1,5 +1,5 @@
 /*
-* Copyright (C) 2015 - 2018 Intel Corporation.
+* Copyright (C) 2015 - 2019 Intel Corporation.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -74,7 +74,7 @@ void StressIncreaseToMax::run()
         }
     }
 
-    if(!scenario_workload.get_allocations_info().size() < task_conf.n &&
+    if(!(scenario_workload.get_allocations_info().size() < task_conf.n) &&
        !has_reach_memory_request_limit)
         printf("\nWARNING: Too few memory operations to reach the limit.\n");
     if(test_status.is_allocation_error) printf("\nWARNING: Allocation error. \n");
@@ -115,7 +115,7 @@ std::vector<iteration_result> StressIncreaseToMax::execute_test_iterations(
 
         results.push_back(stress_test.get_test_status());
 
-        //Log every interation of StressIncreaseToMax test.
+        //Log every iteration of StressIncreaseToMax test.
         csv::Row row;
         row.append(itr);
         row.append(convert_bytes_to_mb(stats.get_allocated()));
