@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2016 Intel Corporation.
+#  Copyright (C) 2016 - 2019 Intel Corporation.
 #  All rights reserved.
 #
 #  Redistribution and use in source and binary forms, with or without
@@ -49,8 +49,8 @@ class Test_autohbw(object):
         print "Executing command: {0}".format(command)
         output, retcode = self.cmd_helper.execute_cmd(command, sudo=False)
         assert retcode == 0, self.fail_msg.format("\nError: autohbw_test_helper returned {0} \noutput: {1}".format(retcode,output))
-        assert self.memkind_malloc_log in output, self.fail_msg.format("\nError: malloc was not overrided by autohbw equivalent \noutput: {0}").format(output)
-        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overrided by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_malloc_log in output, self.fail_msg.format("\nError: malloc was not overridden by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overridden by autohbw equivalent \noutput: {0}").format(output)
 
     def test_TC_MEMKIND_autohbw_calloc_and_free(self):
         """ This test executes ./autohbw_test_helper with LD_PRELOAD that is overriding calloc() and free() to equivalent autohbw functions"""
@@ -58,8 +58,8 @@ class Test_autohbw(object):
         print "Executing command: {0}".format(command)
         output, retcode = self.cmd_helper.execute_cmd(command, sudo=False)
         assert retcode == 0, self.fail_msg.format("\nError: autohbw_test_helper returned {0} \noutput: {1}".format(retcode,output))
-        assert self.memkind_calloc_log in output, self.fail_msg.format("\nError: calloc was not overrided by autohbw equivalent \noutput: {0}").format(output)
-        assert self.memkind_free_log in output, self.fail_msg.format("Error: free was not overrided by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_calloc_log in output, self.fail_msg.format("\nError: calloc was not overridden by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_free_log in output, self.fail_msg.format("Error: free was not overridden by autohbw equivalent \noutput: {0}").format(output)
 
     def test_TC_MEMKIND_autohbw_realloc_and_free(self):
         """ This test executes ./autohbw_test_helper with LD_PRELOAD that is overriding realloc() and free() to equivalent autohbw functions"""
@@ -67,8 +67,8 @@ class Test_autohbw(object):
         print "Executing command: {0}".format(command)
         output, retcode = self.cmd_helper.execute_cmd(command, sudo=False)
         assert retcode == 0, self.fail_msg.format("\nError: autohbw_test_helper returned {0} \noutput: {1}".format(retcode,output))
-        assert self.memkind_realloc_log in output, self.fail_msg.format("\nError: realloc was not overrided by autohbw equivalent \noutput: {0}").format(output)
-        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overrided by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_realloc_log in output, self.fail_msg.format("\nError: realloc was not overridden by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overridden by autohbw equivalent \noutput: {0}").format(output)
 
     def test_TC_MEMKIND_autohbw_posix_memalign_and_free(self):
         """ This test executes ./autohbw_test_helper with LD_PRELOAD that is overriding posix_memalign() and free() to equivalent autohbw functions"""
@@ -76,5 +76,5 @@ class Test_autohbw(object):
         print "Executing command: {0}".format(command)
         output, retcode = self.cmd_helper.execute_cmd(command, sudo=False)
         assert retcode == 0, self.fail_msg.format("\nError: autohbw_test_helper returned {0} \noutput: {1}".format(retcode,output))
-        assert self.memkind_posix_memalign_log in output, self.fail_msg.format("\nError: posix_memalign was not overrided by autohbw equivalent \noutput: {0}").format(output)
-        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overrided by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_posix_memalign_log in output, self.fail_msg.format("\nError: posix_memalign was not overridden by autohbw equivalent \noutput: {0}").format(output)
+        assert self.memkind_free_log in output, self.fail_msg.format("\nError: free was not overridden by autohbw equivalent \noutput: {0}").format(output)
