@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2016 Intel Corporation.
+ * Copyright (C) 2014 - 2018 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,6 +42,9 @@ const int all_error_code[] = {
     MEMKIND_ERROR_TOOMANY,
     MEMKIND_ERROR_BADOPS,
     MEMKIND_ERROR_HUGETLB,
+    MEMKIND_ERROR_ARENAS_CREATE,
+    MEMKIND_ERROR_OPERATION_FAILED,
+    MEMKIND_ERROR_MEMTYPE_NOT_AVAILABLE,
     EINVAL,
     ENOMEM
 };
@@ -63,7 +66,8 @@ TEST_F(ErrorMessage, test_TC_MEMKIND_ErrorMsgLength)
     size_t i;
     char error_message[MEMKIND_ERROR_MESSAGE_SIZE];
     for (i = 0; i < sizeof(all_error_code)/sizeof(all_error_code[0]); ++i) {
-        memkind_error_message(all_error_code[i], error_message, MEMKIND_ERROR_MESSAGE_SIZE);
+        memkind_error_message(all_error_code[i], error_message,
+                              MEMKIND_ERROR_MESSAGE_SIZE);
         EXPECT_TRUE(strlen(error_message) < MEMKIND_ERROR_MESSAGE_SIZE - 1);
     }
     memkind_error_message(MEMKIND_ERROR_UNAVAILABLE, NULL, 0);
@@ -74,7 +78,8 @@ TEST_F(ErrorMessage, test_TC_MEMKIND_ErrorMsgFormat)
     size_t i;
     char error_message[MEMKIND_ERROR_MESSAGE_SIZE];
     for (i = 0; i < sizeof(all_error_code)/sizeof(all_error_code[0]); ++i) {
-        memkind_error_message(all_error_code[i], error_message, MEMKIND_ERROR_MESSAGE_SIZE);
+        memkind_error_message(all_error_code[i], error_message,
+                              MEMKIND_ERROR_MESSAGE_SIZE);
         EXPECT_TRUE(strncmp(error_message, "<memkind>", strlen("<memkind>")) == 0);
     }
 }
@@ -83,6 +88,7 @@ TEST_F(ErrorMessage, test_TC_MEMKIND_ErrorMsgUndefMesg)
 {
     char error_message[MEMKIND_ERROR_MESSAGE_SIZE];
     memkind_error_message(-0xdeadbeef, error_message, MEMKIND_ERROR_MESSAGE_SIZE);
-    EXPECT_TRUE(strncmp(error_message, "<memkind> Undefined error number:", strlen("<memkind> Undefined error number:")) == 0);
+    EXPECT_TRUE(strncmp(error_message, "<memkind> Undefined error number:",
+                        strlen("<memkind> Undefined error number:")) == 0);
 }
 
